@@ -12,7 +12,7 @@ class histograms:
 		if figsize is not None: plt.figure(figsize=figsize)
 
 	def histogram(self, x, num_bins=10, title='', fontsize=12, facecolor='blue', α=0.5, 
-			xlabel='', ylabel='', 
+			xlabel='', ylabel='', ticker_fontsize=9, ticker_rotate=0,
 			path=None, subplot=None, ylogScale=False, showImg=True, normalize=False):
 		'''
 			normalize 	: Show the probability instead of count
@@ -20,7 +20,12 @@ class histograms:
 		'''
 
 		if subplot is not None: plt.subplot(subplot)
-	
+
+
+		plt.tick_params(axis='both', which='both', labelsize=ticker_fontsize)
+		plt.xticks(fontsize=ticker_fontsize, rotation=ticker_rotate)
+		#plt.yticks(fontsize=ticker_fontsize, rotation=ticker_rotate)
+
 		plt.xlabel(xlabel, fontsize=fontsize)
 		plt.ylabel(ylabel, fontsize=fontsize)
 		plt.title(title, fontsize=fontsize)
