@@ -5,7 +5,12 @@ import numpy as np
 
 class lines:
 	"""A class that generates basic line plots"""
-	def __init__(self, title_font=16, xfont=16, yfont=16, figsize=None):
+	def __init__(self, X, Y, title, xlabel, ylabel, imgText=None, outpath=None, 
+					subplot=None, xlim=None, ylim=None, xTextShift=0.05, yTextShift=0.95,
+					ticker_fontsize=9, xTextLoc=None, yTextLoc=None, color='blue', marker=',', showImg=True, 
+					xticker_rotate=0, yticker_rotate=0,
+					xtick_locations=None, xtick_labels=None, ytick_locations=None, ytick_labels=None, 
+					title_font=16, xfont=16, yfont=16, figsize=None):
 		"""calculates the probability that "token" is found in spam emails
 		
 		:param token: (str)
@@ -15,8 +20,16 @@ class lines:
 		self.xfont = xfont
 		self.yfont = yfont
 		self.already_called_plot_line = False
+
 		if figsize is not None: plt.figure(figsize=figsize)
 
+		self.plot_line(X=X, Y=Y, title=title, xlabel=xlabel, ylabel=ylabel, imgText=imgText, outpath=outpath, 
+					subplot=subplot, xlim=xlim, ylim=ylim, xTextShift=xTextShift, yTextShift=yTextShift,
+					ticker_fontsize=ticker_fontsize, xTextLoc=xTextLoc, yTextLoc=yTextLoc, color=color, 
+					marker=marker, showImg=showImg, xticker_rotate=xticker_rotate, yticker_rotate=yticker_rotate,
+					xtick_locations=xtick_locations, xtick_labels=xtick_labels, 
+					ytick_locations=ytick_locations, ytick_labels=ytick_labels)
+
 	def plot_line(self, X, Y, title, xlabel, ylabel, imgText=None, outpath=None, 
 					subplot=None, xlim=None, ylim=None, xTextShift=0.05, yTextShift=0.95,
 					ticker_fontsize=9, xTextLoc=None, yTextLoc=None, color='blue', marker=',', showImg=True, 
@@ -110,6 +123,7 @@ class lines:
 		if imgText is not None: 
 			self.add_text(X, Y, imgText, α=xTextShift, β=yTextShift, xTextLoc=xTextLoc, yTextLoc=yTextLoc)
 
+		plt.tight_layout()
 		if save_path is None: plt.show()
 		else: plt.savefig(save_path)
 
